@@ -1,5 +1,3 @@
-#! /usr/bin/env python3
-# -*- coding: utf-8 -*-
 #
 # BSD 3-Clause License
 #
@@ -48,13 +46,13 @@ Authors:
 import copy
 import itertools
 import logging
-from . import dsp
-from . import naming
+
+from . import dsp, naming
 
 logger = logging.getLogger(__name__)
 
 
-class TDICombination():
+class TDICombination:
     """Defines a time-delay interferometry (TDI) combination.
 
     To create a combination, pass a component dictionary containing the measurements
@@ -82,14 +80,15 @@ class TDICombination():
         logger.info("Initializing combination with components '%s'", components)
         #: dict: Dictionary of components.
         #:
-        #: This is the dictionary of measurements associated with the list of time-shift
-        #: polynomials, as couples ``(factor, operators)``.
+        #: This is the dictionary of measurements associated with the list of
+        #: time-shift polynomials, as couples ``(factor, operators)``.
         #:
-        #: Refer to the documentation of :class:`pytdi.TDICombination` for more information.
+        #: Refer to the documentation of :class:`pytdi.TDICombination` for more
+        #: information.
         self.components = dict(components)
 
     @classmethod
-    def from_string(cls, string, var_name='eta', half_way_shift=True):
+    def from_string(cls, string, var_name="eta", half_way_shift=True):
         """Initialize a combination from virtual photon paths.
 
         Following the geometrical interpretation proposed by M. Vallisneri, you can
@@ -111,12 +110,12 @@ class TDICombination():
         if not string:
             return cls({})
 
-        beams = string.split(' ')
+        beams = string.split(" ")
         combination = cls({})
         total_shifts = []
 
         for beam in beams:
-            if beam[0] == '-':
+            if beam[0] == "-":
                 is_delay = True
                 beam = beam[1:]
             else:
@@ -125,19 +124,25 @@ class TDICombination():
             indices = [int(i) for i in beam]
             for i, j in zip(indices[:-1], indices[1:]):
                 if is_delay:
-                    combination -= total_shifts * cls({naming.join_indices(var_name, i, j): [(1, [])]})
+                    combination -= total_shifts * cls(
+                        {naming.join_indices(var_name, i, j): [(1, [])]}
+                    )
                     total_shifts.append(naming.join_indices("D", i, j))
                 else:
-                    combination += total_shifts * cls({
-                        naming.join_indices(var_name, j, i): [(1, [naming.join_indices("A", i, j)])]
-                    })
+                    combination += total_shifts * cls(
+                        {
+                            naming.join_indices(var_name, j, i): [
+                                (1, [naming.join_indices("A", i, j)])
+                            ]
+                        }
+                    )
                     total_shifts.append(naming.join_indices("A", i, j))
 
         if half_way_shift:
             half_shifts_inv = []
-            for operator in reversed(total_shifts[:len(total_shifts)//2]):
+            for operator in reversed(total_shifts[: len(total_shifts) // 2]):
                 name, i, j = naming.split_indices(operator)
-                name_inv = 'D' if name == 'A' else 'A'
+                name_inv = "D" if name == "A" else "A"
                 half_shifts_inv.append(naming.join_indices(name_inv, j, i))
             return half_shifts_inv * combination
         return combination
@@ -171,7 +176,9 @@ class TDICombination():
                         advancements.add(operator)
         return advancements
 
-    def build_shifts(self, delays, fs, delay_derivatives=None, order=5, delta=1e-12, maxiter=10):
+    def build_shifts(
+        self, delays, fs, delay_derivatives=None, *, order=5, delta=1e-12, maxiter=10
+    ):
         """Precompute total shifts.
 
         Nested time-shifts are iteratively constructed from atomic time-shifts.
@@ -205,20 +212,26 @@ class TDICombination():
             logger.debug("Computing delay '%s'", delay)
             # split off indices from delay operator D_ij
             _, i, j = naming.split_indices(delay)
-            shifts[(delay, )] = -delays[naming.join_indices('d', i, j)]
+            shifts[(delay,)] = -delays[naming.join_indices("d", i, j)]
             if delay_derivatives:
                 logger.debug("Computing delay derivative '%s'", delay)
-                derivatives[(delay, )] = -delay_derivatives[naming.join_indices('d', i, j)]
+                derivatives[(delay,)] = -delay_derivatives[
+                    naming.join_indices("d", i, j)
+                ]
         logger.debug("Computing advancements")
         for advancement in self.advancements:
             logger.debug("Computing advancement '%s'", advancement)
             _, i, j = naming.split_indices(advancement)
-            delay = naming.join_indices('d', j, i)
-            shifts[(advancement, )] = dsp.calculate_advancements(delays[delay], fs, order, delta, maxiter)
+            delay = naming.join_indices("d", j, i)
+            shifts[(advancement,)] = dsp.calculate_advancements(
+                delays[delay], fs, order, delta, maxiter
+            )
             if delay_derivatives:
                 logger.debug("Computing advancement derivative '%s'", advancement)
-                dotd_advanced = dsp.timeshift(delay_derivatives[delay], shifts[(advancement, )] * fs)
-                derivatives[(advancement, )] = dotd_advanced / (1 - dotd_advanced)
+                dotd_advanced = dsp.timeshift(
+                    delay_derivatives[delay], shifts[(advancement,)] * fs
+                )
+                derivatives[(advancement,)] = dotd_advanced / (1 - dotd_advanced)
 
         # Find set of all nested operators
         nested_operators = set()
@@ -233,9 +246,11 @@ class TDICombination():
             nested_derivatives = 0
             for atom in operator:
                 if delay_derivatives:
-                    atomic_derivatives = derivatives[(atom, )]
-                    nested_derivatives += dsp.timeshift(atomic_derivatives, nested_shifts * fs, order)
-                atomic_shifts = shifts[(atom, )]
+                    atomic_derivatives = derivatives[(atom,)]
+                    nested_derivatives += dsp.timeshift(
+                        atomic_derivatives, nested_shifts * fs, order
+                    )
+                atomic_shifts = shifts[(atom,)]
                 nested_shifts += dsp.timeshift(atomic_shifts, nested_shifts * fs, order)
             shifts[operator] = nested_shifts
             derivatives[operator] = nested_derivatives
@@ -243,12 +258,14 @@ class TDICombination():
             return shifts, derivatives
         return shifts, None
 
-    def build(self, delays, fs, delay_derivatives=None, order=5, delta=1e-12, maxiter=10):
+    def build(
+        self, delays, fs, delay_derivatives=None, *, order=5, delta=1e-12, maxiter=10
+    ):
         """Prepare the combination for a set of delays.
 
-        This function prepares the actual combination by pre-computing nested delays and
-        Doppler factors. It returns a callable object that evaluates the combination for a
-        given set of measurements.
+        This function prepares the actual combination by pre-computing nested
+        delays and Doppler factors. It returns a callable object that evaluates
+        the combination for a given set of measurements.
 
         .. code-block:: python
 
@@ -259,8 +276,8 @@ class TDICombination():
                 {'y_12': y12_array,'y_21': y21_array},
             )
 
-        If any advancement operators are used in the combination, they are computed
-        iteratively.
+        If any advancement operators are used in the combination, they are
+        computed iteratively.
 
         Args:
             delays (dict): dictionary of delays [s]
@@ -275,14 +292,18 @@ class TDICombination():
             and accepting the following arguments:
 
             * **measurements** (*dict*): dictionary of measurements
-            * **order** (*int*): Lagrange interpolation orders for measurement interpolations
-            * **unit** (*str*): unit of measurements, one of ``'phase'``, ``'frequency'``
+            * **order** (*int*): Lagrange interpolation orders for measurement
+              interpolations
+            * **unit** (*str*): unit of measurements, one of ``'phase'``,
+              ``'frequency'``
         """
         logger.info("Building combination '%s'", self)
 
-        shifts, derivatives = self.build_shifts(delays, fs, delay_derivatives, order, delta, maxiter)
+        shifts, derivatives = self.build_shifts(
+            delays, fs, delay_derivatives, order=order, delta=delta, maxiter=maxiter
+        )
 
-        def call(measurements, order=31, unit='frequency'):
+        def call(measurements, order=31, unit="frequency"):
             """Evaluate combination for a set of measurements."""
             logger.info("Evaluate combination '%s'", self)
 
@@ -291,22 +312,28 @@ class TDICombination():
 
             result = 0
             for measurement, polynomial in self.components.items():
-                logger.debug("Computing contributions from measurement '%s'", measurement)
+                logger.debug(
+                    "Computing contributions from measurement '%s'", measurement
+                )
                 for factor, operator in polynomial:
                     # Shift the data, and add it to the result
                     shift = shifts[tuple(operator)]
-                    shifted = dsp.timeshift(measurements[measurement], shift * fs, order)
-                    if unit == 'phase':
+                    shifted = dsp.timeshift(
+                        measurements[measurement], shift * fs, order
+                    )
+                    if unit == "phase":
                         result += factor * shifted
-                    elif unit == 'frequency':
+                    elif unit == "frequency":
                         if derivatives:
                             derivative = derivatives[tuple(operator)]
                         else:
                             derivative = dsp.diff(shift, 1 / fs)
                         result += factor * (1 + derivative) * shifted
                     else:
-                        raise ValueError(f"Unit '{unit}' not available, choose one of "
-                                          "'phase', 'frequency'.")
+                        raise ValueError(
+                            f"Unit '{unit}' not available, choose one of "
+                            "'phase', 'frequency'."
+                        )
             return result
 
         return call
@@ -322,12 +349,17 @@ class TDICombination():
         Returns:
             A new combination, result of the transformation.
         """
+
         def transform_string(string, mapping):
             name, i, j = naming.split_indices(string)
             if i not in mapping:
-                raise ValueError(f"Incomplete mapping '{mapping}', should contain index '{i}'.")
+                raise ValueError(
+                    f"Incomplete mapping '{mapping}', should contain index '{i}'."
+                )
             if j not in mapping:
-                raise ValueError(f"Incomplete mapping '{mapping}', should contain index '{j}'.")
+                raise ValueError(
+                    f"Incomplete mapping '{mapping}', should contain index '{j}'."
+                )
             i, j = mapping[i], mapping[j]
             return naming.join_indices(name, i, j)
 
@@ -336,27 +368,37 @@ class TDICombination():
         transformed.components = {}
         for measurement, polynomial in self.components.items():
             transformed_meas = transform_string(measurement, mapping)
-            logger.debug("Transforming measurement '%s' into '%s'", measurement, transformed_meas)
+            logger.debug(
+                "Transforming measurement '%s' into '%s'", measurement, transformed_meas
+            )
             if transformed_meas in transformed.components:
                 raise ValueError(f"Invalid mapping '{mapping}', should be a bijection.")
             transformed.components[transformed_meas] = []
             for factor, operators in polynomial:
-                transformed_term = (factor, [transform_string(operator, mapping) for operator in operators])
-                logger.debug("Transforming term '%s' into '%s'", operators, transformed_term)
+                transformed_term = (
+                    factor,
+                    [transform_string(operator, mapping) for operator in operators],
+                )
+                logger.debug(
+                    "Transforming term '%s' into '%s'", operators, transformed_term
+                )
                 transformed.components[transformed_meas].append(transformed_term)
         return transformed
 
     def simplified(self):
         """Return a simplified unique representation of the combination.
 
-        We try to apply the following rules, for each time-shift operator polynomial:
+        We try to apply the following rules, for each time-shift operator
+        polynomial:
 
             * drop polynomial if vanishing,
             * drop terms with a vanishing factor,
-            * collect terms with identifical time-shift operators with a unique factor,
+            * collect terms with identifical time-shift operators with a unique
+              factor,
             * drop delay and advancement operator which cancel out.
 
-        We then sort the components of the simplified combination to get a unique representative.
+        We then sort the components of the simplified combination to get a
+        unique representative.
 
         Returns:
             A new combination, simplified version of the one passed as argument.
@@ -366,7 +408,9 @@ class TDICombination():
         for measurement, polynomial in simplified.components.items():
             # Drop variables that are not used
             if not polynomial:
-                logger.debug("Empty polynomial for measurement '%s', removing", measurement)
+                logger.debug(
+                    "Empty polynomial for measurement '%s', removing", measurement
+                )
                 del simplified.components[measurement]
                 return simplified.simplified()
             # Drop term with vanishing factor
@@ -376,20 +420,39 @@ class TDICombination():
                     simplified.components[measurement].remove((factor, operators))
                     return simplified.simplified()
             # Collect terms with identical time-shift operator
-            for (factor1, operators1), (factor2, operators2) in itertools.combinations(polynomial, 2):
+            for (factor1, operators1), (factor2, operators2) in itertools.combinations(
+                polynomial, 2
+            ):
                 if operators1 == operators2:
-                    logger.debug("Collecting factors '%s' and '%s' for term '%s'", factor1, factor2, operators1)
+                    logger.debug(
+                        "Collecting factors '%s' and '%s' for term '%s'",
+                        factor1,
+                        factor2,
+                        operators1,
+                    )
                     simplified.components[measurement].remove((factor1, operators1))
                     simplified.components[measurement].remove((factor2, operators2))
-                    simplified.components[measurement].append((factor1 + factor2, operators1))
+                    simplified.components[measurement].append(
+                        (factor1 + factor2, operators1)
+                    )
                     return simplified.simplified()
             # Simplify successive delay and advancement operation
             for factor, operators in list(polynomial):
-                for i, (operator1, operator2) in enumerate(zip(operators, operators[1:])):
+                for i, (operator1, operator2) in enumerate(
+                    zip(operators, operators[1:])
+                ):
                     name1, i1, j1 = naming.split_indices(operator1)
                     name2, i2, j2 = naming.split_indices(operator2)
-                    if (name1, name2) in [("A", "D"), ("D", "A")] and i1 == j2 and j1 == i2:
-                        logger.debug("Cancelling operators '%s' and '%s', removing", operator1, operator2)
+                    if (
+                        (name1, name2) in [("A", "D"), ("D", "A")]
+                        and i1 == j2
+                        and j1 == i2
+                    ):
+                        logger.debug(
+                            "Cancelling operators '%s' and '%s', removing",
+                            operator1,
+                            operator2,
+                        )
                         del operators[i + 1]
                         del operators[i]
                         return simplified.simplified()
@@ -408,7 +471,7 @@ class TDICombination():
 
     def __add__(self, other):
         if not isinstance(other, TDICombination):
-            TypeError(f"Unsupported operand type(s) for +: '{type(self)}' and '{type(other)}'.")
+            return NotImplemented
 
         logger.info("Adding combinations '%s' and '%s'", self, other)
         summation = copy.deepcopy(self)
@@ -428,21 +491,25 @@ class TDICombination():
         elif isinstance(other, (int, float)):
             factor_other, operators_other = other, []
         else:
-            TypeError(f"unsupported operand type(s) for *: '{type(other)}' and '{type(self)}'.")
+            return NotImplemented
 
-        logger.info("Multiplying term '%s %s' and '%s'", factor_other, operators_other, self)
+        logger.info(
+            "Multiplying term '%s %s' and '%s'", factor_other, operators_other, self
+        )
         product = copy.deepcopy(self)
         for measurement, polynomial in self.components.items():
             for factor, operators in polynomial:
                 product.components[measurement].remove((factor, operators))
-                product.components[measurement].append((factor_other * factor, operators_other + operators))
+                product.components[measurement].append(
+                    (factor_other * factor, operators_other + operators)
+                )
 
         return product.simplified()
 
     def __truediv__(self, other):
         if isinstance(other, (int, float)):
             return (1 / other) * self
-        raise TypeError(f"unsupported operand type(s) for /: '{type(self)}' and '{type(other)}'.")
+        return NotImplemented
 
     def __neg__(self):
         return (-1) * self
@@ -492,6 +559,8 @@ class LISATDICombination(TDICombination):
             mapping = {1: 2, 2: 3, 3: 1}
         elif nrot == 2:
             mapping = {1: 3, 2: 1, 3: 2}
+        else:
+            raise ValueError(f"nrot must be 0, 1 or 2 (got {nrot})")
 
         return self.transformed(mapping)
 
@@ -523,18 +592,22 @@ class LISATDICombination(TDICombination):
 
 
 class LISAClockCorrection:
-    """Defines a quantity in which clock noise enters similarily to a LISA TDI combination.
-
-    Clock-noise corrections are automatically built from a :class:`pytdi.LISATDICombination`.
-    To compute a clock noise-free combination, evaluate the difference of this combination
-    and the correction quantity built with this class.
+    """Defines a quantity in which clock noise enters similarily to combination.
 
+    Clock-noise corrections are automatically built from a
+    :class:`pytdi.LISATDICombination`. To compute a clock noise-free
+    combination, evaluate the difference of this combination and the correction
+    quantity built with this class.
 
     Args:
-        combination (:class:`pytdi.LISATDICombination`): uncorrected combination
-        modulation_freqs (dict): constant modulation frequencies [Hz]
-        modulation_reduction (bool): removes right-sided modulation noise using RFI sidebands
+        combination (:class:`pytdi.LISATDICombination`):
+            uncorrected combination
+        modulation_freqs (dict):
+            constant modulation frequencies [Hz]
+        modulation_reduction (bool):
+            removes right-sided modulation noise using REF sidebands
     """
+
     # pylint: disable=invalid-name
 
     def __init__(self, combination, modulation_freqs=None, modulation_reduction=True):
@@ -544,57 +617,87 @@ class LISAClockCorrection:
             #: :class:`pytdi.LISATDICombination`: Uncorrected combination.
             self.combination = combination
         else:
-            raise TypeError(f"invalid combination type {type(combination)}, use LISATDICombination")
+            raise TypeError(
+                f"invalid combination type {type(combination)}, use LISATDICombination"
+            )
 
-        logger.info("Initializing clock-noise correction from combination '%s'", self.combination)
+        logger.info(
+            "Initializing clock-noise correction from combination '%s'",
+            self.combination,
+        )
 
-        # Use default set of modulation frequencies, matching that of LISANode and Instrument
+        # Use default set of modulation frequencies, matching that of LISANode
+        # and Instrument
         if modulation_freqs is None:
             modulation_freqs = {
-                '12': 2.4E9, '23': 2.4E9, '31': 2.4E9,
-                '13': 2.401E9, '32': 2.401E9, '21': 2.401E9,
+                "12": 2.4e9,
+                "23": 2.4e9,
+                "31": 2.4e9,
+                "13": 2.401e9,
+                "32": 2.401e9,
+                "21": 2.401e9,
             }
 
-        # Check that only a single measurement name (`var_name`) is found in `combination`
+        # Check that only a single measurement name (`var_name`) is found in
+        # `combination`
         var_name = None
         for measurement in combination.measurements:
             new_name, _, _ = naming.split_indices(measurement)
             if var_name is None:
                 var_name = new_name
             elif var_name != new_name:
-                raise ValueError(f"single measurement name allowed, found '{new_name}' and '{var_name}'")
+                raise ValueError(
+                    "single measurement name allowed, "
+                    f"found '{new_name}' and '{var_name}'"
+                )
 
         # Build `Delta_M_ij`
         if modulation_reduction:
             logger.debug("Building the differential modulation noise (ΔM) combinations")
             self.delta_M = {
-                i: LISATDICombination({
-                    f'rfi_sb_{i}{k}': [(1/2, [])],
-                    f'rfi_{i}{k}': [(-1/2, [])],
-                    f'rfi_sb_{i}{j}': [(-1/2, [])],
-                    f'rfi_{i}{j}': [(1/2, [])],
-                })
-                for i, j, k in ['123', '231', '312']
+                i: LISATDICombination(
+                    {
+                        f"ref_sb_{i}{k}": [(1 / 2, [])],
+                        f"ref_{i}{k}": [(-1 / 2, [])],
+                        f"ref_sb_{i}{j}": [(-1 / 2, [])],
+                        f"ref_{i}{j}": [(1 / 2, [])],
+                    }
+                )
+                for i, j, k in ["123", "231", "312"]
             }
         else:
-            self.delta_M = {i: LISATDICombination({}) for i in '123'}
-        delta_M_set = {f'Delta_M_{i}': self.delta_M[i] for i in self.delta_M}
+            self.delta_M = {i: LISATDICombination({}) for i in "123"}
+        delta_M_set = {f"Delta_M_{i}": self.delta_M[i] for i in self.delta_M}
 
         # Build `r_ij`
-        logger.debug("Building the modulation-corrected clock-correction variables (rc)")
+        logger.debug(
+            "Building the modulation-corrected clock-correction variables (rc)"
+        )
         self.rc = {}
-        for i, j, k in ['123', '231', '312']:
-            self.rc[f'{i}{j}'] = LISATDICombination({
-                f'isi_sb_{i}{j}': [(1 / modulation_freqs[f'{j}{i}'], [])],
-                f'isi_{i}{j}': [(-1 / modulation_freqs[f'{j}{i}'], [])],
-                f'Delta_M_{j}': [(1 / modulation_freqs[f'{j}{i}'], [f'D_{i}{j}'])],
-            }) @ delta_M_set
-            self.rc[f'{i}{k}'] = LISATDICombination({
-                f'isi_sb_{i}{k}': [(1 / modulation_freqs[f'{k}{i}'], [])],
-                f'isi_{i}{k}': [(-1 / modulation_freqs[f'{k}{i}'], [])],
-                f'Delta_M_{i}': [(-1 / modulation_freqs[f'{k}{i}'], [])],
-            }) @ delta_M_set
-        rc_set = {f'rc_{mosa}': rc for mosa, rc in self.rc.items()}
+        for i, j, k in ["123", "231", "312"]:
+            self.rc[f"{i}{j}"] = (
+                LISATDICombination(
+                    {
+                        f"sci_sb_{i}{j}": [(1 / modulation_freqs[f"{j}{i}"], [])],
+                        f"sci_{i}{j}": [(-1 / modulation_freqs[f"{j}{i}"], [])],
+                        f"Delta_M_{j}": [
+                            (1 / modulation_freqs[f"{j}{i}"], [f"D_{i}{j}"])
+                        ],
+                    }
+                )
+                @ delta_M_set
+            )
+            self.rc[f"{i}{k}"] = (
+                LISATDICombination(
+                    {
+                        f"sci_sb_{i}{k}": [(1 / modulation_freqs[f"{k}{i}"], [])],
+                        f"sci_{i}{k}": [(-1 / modulation_freqs[f"{k}{i}"], [])],
+                        f"Delta_M_{i}": [(-1 / modulation_freqs[f"{k}{i}"], [])],
+                    }
+                )
+                @ delta_M_set
+            )
+        rc_set = {f"rc_{mosa}": rc for mosa, rc in self.rc.items()}
 
         # Build `P_ij`
         # Note that `P_component` here is denoted `P_ij` in the article, while
@@ -603,19 +706,24 @@ class LISAClockCorrection:
         self.P = {}
         self.P_component = {}
         for i, j in naming.lisa_indices():
-            self.P_component[f'{i}{j}'] = self.combination.components.get(f'{var_name}_{i}{j}', [])
-            self.P[f'{i}{j}'] = LISATDICombination({f'rc_{i}{j}': self.P_component[f'{i}{j}']}) @ rc_set
+            self.P_component[f"{i}{j}"] = self.combination.components.get(
+                f"{var_name}_{i}{j}", []
+            )
+            self.P[f"{i}{j}"] = (
+                LISATDICombination({f"rc_{i}{j}": self.P_component[f"{i}{j}"]}) @ rc_set
+            )
 
         # Build `R_ij`
         logger.debug("Building the reconstructed photon path (R)")
         self.R_rc = {}
         self.R = {}
         for i, j in naming.lisa_indices():
-            self.R_rc[f'{i}{j}'] = LISATDICombination({})
-            for coeff, delays in self.P_component[f'{i}{j}']:
-                self.R_rc[f'{i}{j}'] -= coeff * LISATDICombination.from_string(
-                    self.to_string(delays), half_way_shift=False, var_name='rc')
-            self.R[f'{i}{j}'] = self.R_rc[f'{i}{j}'] @ rc_set
+            self.R_rc[f"{i}{j}"] = LISATDICombination({})
+            for coeff, delays in self.P_component[f"{i}{j}"]:
+                self.R_rc[f"{i}{j}"] -= coeff * LISATDICombination.from_string(
+                    self.to_string(delays), half_way_shift=False, var_name="rc"
+                )
+            self.R[f"{i}{j}"] = self.R_rc[f"{i}{j}"] @ rc_set
 
     @staticmethod
     def to_string(delays):
@@ -627,20 +735,22 @@ class LISAClockCorrection:
         components = []
         for delay in delays:
             operator, i, j = naming.split_indices(delay)
-            if operator == 'D':
-                components.append(f'-{i}{j}')
-            elif operator == 'A':
-                components.append(f'{i}{j}')
+            if operator == "D":
+                components.append(f"-{i}{j}")
+            elif operator == "A":
+                components.append(f"{i}{j}")
             else:
-                raise ValueError(f"unsupported time-shift operator '{operator}', use 'A' or 'D'")
-        return ' '.join(components)
+                raise ValueError(
+                    f"unsupported time-shift operator '{operator}', use 'A' or 'D'"
+                )
+        return " ".join(components)
 
     def build(self, *args, **kwargs):
         """Prepare the clock-noise correction from delays.
 
-        This function prepares the actual correction by pre-computing nested delays and
-        Doppler factors. It returns a callable object that evaluates the correction for a
-        given set of measurements.
+        This function prepares the actual correction by pre-computing nested
+        delays and Doppler factors. It returns a callable object that evaluates
+        the correction for a given set of measurements.
 
         .. code-block:: python
 
@@ -651,8 +761,8 @@ class LISAClockCorrection:
                 {'y_12': y12_array,'y_21': y21_array},
             )
 
-        If any advancement operators are used in the combination, they are computed
-        iteratively.
+        If any advancement operators are used in the combination, they are
+        computed iteratively.
 
         Args:
             delays (dict): dictionary of delays [s]
@@ -668,22 +778,18 @@ class LISAClockCorrection:
 
             * **measurements** (*dict*): measurements, including sidebands [Hz]
             * **beatnote_freqs** (*dict*): beatnote frequencies [Hz]
-            * **order** (*int*): Lagrange interpolation orders for measurement interpolations
-            * **individual_rij** (*bool*): compute ``R_ij`` for each term individually
+            * **order** (*int*): Lagrange interpolation orders for measurement
+              interpolations
+            * **individual_rij** (*bool*): compute ``R_ij`` for each term
+              individually
         """
         logger.info("Building clock-noise correction from combination")
 
         # Build the `P_ij`
-        prepared_P = {
-            mosa: P.build(*args, **kwargs)
-            for mosa, P in self.P.items()
-        }
+        prepared_P = {mosa: P.build(*args, **kwargs) for mosa, P in self.P.items()}
 
         # Build the `R_ij`
-        prepared_R = {
-            mosa: R.build(*args, **kwargs)
-            for mosa, R in self.R.items()
-        }
+        prepared_R = {mosa: R.build(*args, **kwargs) for mosa, R in self.R.items()}
 
         def call(measurements, beatnote_freqs, order=31, individual_rij=True):
             """Evaluate clock-noise correction for a set of measurements."""
@@ -691,28 +797,52 @@ class LISAClockCorrection:
             if individual_rij:
                 # prepare rescaled measurements
                 rescaled_measurements = {}
-                for i, j, k in ['123', '231', '312']:
-                    rescaled_measurements[f'rfi_{i}{j}'] = {key: beatnote_freqs[f'rfi_{i}{j}'] * value \
-                        for key, value in measurements.items()}
-                    rescaled_measurements[f'isi_{i}{j}'] = {key: beatnote_freqs[f'isi_{i}{j}'] * value \
-                        for key, value in measurements.items()}
-                    rescaled_measurements[f'isi_{i}{k}'] = {key: beatnote_freqs[f'isi_{i}{k}'] * value \
-                        for key, value in measurements.items()}
+                for i, j, k in ["123", "231", "312"]:
+                    rescaled_measurements[f"ref_{i}{j}"] = {
+                        key: beatnote_freqs[f"ref_{i}{j}"] * value
+                        for key, value in measurements.items()
+                    }
+                    rescaled_measurements[f"sci_{i}{j}"] = {
+                        key: beatnote_freqs[f"sci_{i}{j}"] * value
+                        for key, value in measurements.items()
+                    }
+                    rescaled_measurements[f"sci_{i}{k}"] = {
+                        key: beatnote_freqs[f"sci_{i}{k}"] * value
+                        for key, value in measurements.items()
+                    }
                 # compute correction
-                for i, j, k in ['123', '231', '312']:
-                    result += prepared_R[f'{i}{j}'](rescaled_measurements[f'rfi_{j}{k}'], order=order) \
-                        - prepared_R[f'{i}{j}'](rescaled_measurements[f'isi_{i}{j}'], order=order) \
-                        - prepared_R[f'{i}{k}'](rescaled_measurements[f'rfi_{i}{j}'], order=order) \
-                        - prepared_R[f'{i}{k}'](rescaled_measurements[f'isi_{i}{k}'], order=order) \
-                        + prepared_P[f'{i}{j}'](rescaled_measurements[f'rfi_{j}{k}'], order=order)
+                for i, j, k in ["123", "231", "312"]:
+                    result += (
+                        prepared_R[f"{i}{j}"](
+                            rescaled_measurements[f"ref_{j}{k}"], order=order
+                        )
+                        - prepared_R[f"{i}{j}"](
+                            rescaled_measurements[f"sci_{i}{j}"], order=order
+                        )
+                        - prepared_R[f"{i}{k}"](
+                            rescaled_measurements[f"ref_{i}{j}"], order=order
+                        )
+                        - prepared_R[f"{i}{k}"](
+                            rescaled_measurements[f"sci_{i}{k}"], order=order
+                        )
+                        + prepared_P[f"{i}{j}"](
+                            rescaled_measurements[f"ref_{j}{k}"], order=order
+                        )
+                    )
             else:
                 # compute correction
-                for i, j, k in ['123', '231', '312']:
-                    result += (beatnote_freqs[f'rfi_{j}{k}'] - beatnote_freqs[f'isi_{i}{j}']) \
-                        * prepared_R[f'{i}{j}'](measurements, order=order) \
-                        - (beatnote_freqs[f'rfi_{i}{j}'] + beatnote_freqs[f'isi_{i}{k}']) \
-                        * prepared_R[f'{i}{k}'](measurements, order=order) \
-                        + beatnote_freqs[f'rfi_{j}{k}'] * prepared_P[f'{i}{j}'](measurements, order=order)
+                for i, j, k in ["123", "231", "312"]:
+                    result += (
+                        (beatnote_freqs[f"ref_{j}{k}"] - beatnote_freqs[f"sci_{i}{j}"])
+                        * prepared_R[f"{i}{j}"](measurements, order=order)
+                        - (
+                            beatnote_freqs[f"ref_{i}{j}"]
+                            + beatnote_freqs[f"sci_{i}{k}"]
+                        )
+                        * prepared_R[f"{i}{k}"](measurements, order=order)
+                        + beatnote_freqs[f"ref_{j}{k}"]
+                        * prepared_P[f"{i}{j}"](measurements, order=order)
+                    )
             return result
 
         return call
@@ -730,18 +860,22 @@ class LISAClockCorrection:
             bool: Whether the clock-noise correction is valid.
         """
         test_rc = {
-            f'{i}{j}': LISATDICombination({f'q_{i}': [(-1, [])], f'q_{j}': [(1, [f'D_{i}{j}'])]})
+            f"{i}{j}": LISATDICombination(
+                {f"q_{i}": [(-1, [])], f"q_{j}": [(1, [f"D_{i}{j}"])]}
+            )
             for i, j in naming.lisa_indices()
         }
-        test_rc_set = {f'rc_{mosa}': test_rc[mosa] for mosa in test_rc}
+        test_rc_set = {f"rc_{mosa}": test_rc[mosa] for mosa in test_rc}
 
         # Check that P_ij q_i = R_ij for all i, j
         for i, j in naming.lisa_indices():
-            P_q = LISATDICombination({f'q_{i}': self.P_component[f'{i}{j}']}).simplified()
-            if self.R_rc[f'{i}{j}'] @ test_rc_set != P_q:
+            P_q = LISATDICombination(
+                {f"q_{i}": self.P_component[f"{i}{j}"]}
+            ).simplified()
+            if self.R_rc[f"{i}{j}"] @ test_rc_set != P_q:
                 return False
 
         return True
 
     def __repr__(self):
-        return f'<{self.__class__.__name__} based on {self.combination}>'
+        return f"<{self.__class__.__name__} based on {self.combination}>"
