@@ -1,5 +1,3 @@
-#! /usr/bin/env python3
-# -*- coding: utf-8 -*-
 #
 # BSD 3-Clause License
 #
@@ -42,6 +40,7 @@ Collections of methods for digital signal processing.
 """
 
 import logging
+
 import numpy as np
 
 logger = logging.getLogger(__name__)
@@ -59,6 +58,7 @@ def diff(data, dt):
     """
     return 0 if np.isscalar(data) else np.gradient(data, dt)
 
+
 def timeshift(data, shifts, order=31):
     """Time-shift data (delay or advancement) using Lagrange interpolation.
 
@@ -107,37 +107,44 @@ def timeshift(data, shifts, order=31):
 
     logger.debug("Computing Lagrange coefficients")
     halfp = (order + 1) // 2
-    shift_ints = np.floor(shifts).astype(int)
+    shift_ints = np.floor(shifts)
     shift_fracs = shifts - shift_ints
     taps = lagrange_taps(shift_fracs, halfp)
+    shift_ints = shift_ints.astype(int)
 
     # Handle constant shifts
     if shifts.size == 1:
         logger.debug("Constant shifts, using correlation method")
         i_min = shift_ints - (halfp - 1)
         i_max = shift_ints + halfp + data.size
-        if i_max - 1 < 0:
-            return np.repeat(data[0], data.size)
-        if i_min > data.size - 1:
-            return np.repeat(data[-1], data.size)
-        logger.debug("Padding data (left=%d, right=%d)", max(0, -i_min), max(0, i_max - data.size))
-        data_trimmed = data[max(0, i_min):min(data.size, i_max)]
-        data_padded = np.pad(data_trimmed, (max(0, -i_min), max(0, i_max - data.size)), mode='edge')
+        if i_max - 1 < 0 or i_min > data.size - 1:
+            return np.zeros(data.size)
+        logger.debug(
+            "Padding data (left=%d, right=%d)",
+            max(0, -i_min),
+            max(0, i_max - data.size),
+        )
+        data_trimmed = data[max(0, i_min) : min(data.size, i_max)]
+        data_padded = np.pad(data_trimmed, (max(0, -i_min), max(0, i_max - data.size)))
         logger.debug("Computing correlation product")
-        return np.correlate(data_padded, taps[0], mode='valid')
+        return np.correlate(data_padded, taps[0], mode="valid")
 
     # Check that sizes or compatible
     if data.size != shifts.size:
-        raise ValueError(f"`data` and `shift` must be of the same size (got {data.size}, {shifts.size})")
+        raise ValueError(
+            f"data and shift must be of the same size (got {data.size}, {shifts.size})"
+        )
 
     # Handle time-varying shifts
     logger.debug("Time-varying shifts, using sliding window view")
-    indices = np.clip(np.arange(data.size) + shift_ints, -(halfp + 1), data.size + (halfp - 1))
+    indices = np.clip(
+        np.arange(data.size) + shift_ints, -(halfp + 1), data.size + (halfp - 1)
+    )
     padded = np.pad(data, 2 * halfp)
     slices = np.lib.stride_tricks.sliding_window_view(padded, 2 * halfp)
     slices = slices[indices + 2 * halfp - (halfp - 1)]
     logger.debug("Computing matrix-vector product")
-    return np.einsum('ij,ij->i', taps, slices)
+    return np.einsum("ij,ij->i", taps, slices)
 
 
 def lagrange_taps(shift_fracs, halfp):
@@ -154,10 +161,10 @@ def lagrange_taps(shift_fracs, halfp):
         array-like: Array of Lagrange coefficients, of dimension ``(N, 2 * halfp)``
         if N is the dimension of ``shift_fracs``.
     """
-    taps = np.zeros((2 * halfp, shift_fracs.size))
+    taps = np.zeros((2 * halfp, shift_fracs.size), dtype=shift_fracs.dtype)
 
     if halfp > 1:
-        factor = np.ones(shift_fracs.size, dtype=np.float64)
+        factor = np.ones(shift_fracs.size, dtype=shift_fracs.dtype)
         factor *= shift_fracs * (1 - shift_fracs)
 
         for j in range(1, halfp):
@@ -169,7 +176,7 @@ def lagrange_taps(shift_fracs, halfp):
         taps[halfp] = shift_fracs
 
         for j in range(2, halfp):
-            taps *= 1 - (shift_fracs / j)**2
+            taps *= 1 - (shift_fracs / j) ** 2
 
         taps *= (1 + shift_fracs) * (1 - shift_fracs / halfp)
     else:
@@ -178,6 +185,7 @@ def lagrange_taps(shift_fracs, halfp):
 
     return taps.T
 
+
 def calculate_advancements(delays, fs, order=5, delta=1e-12, maxiter=10):
     r"""Solve for advancements using delays as inputs.
 
@@ -199,8 +207,13 @@ def calculate_advancements(delays, fs, order=5, delta=1e-12, maxiter=10):
     Returns:
         array-like: Array of time advancements, same dimension as ``delays``.
     """
-    logger.debug("Computing advancements from delays, solving for implicit equation "
-                 "(order=%d, delta=%f, maxiter=%d)", order, delta, maxiter)
+    logger.debug(
+        "Computing advancements from delays, solving for implicit equation "
+        "(order=%d, delta=%f, maxiter=%d)",
+        order,
+        delta,
+        maxiter,
+    )
 
     delays = np.asarray(delays)
     if delays.size == 1:
@@ -215,8 +228,11 @@ def calculate_advancements(delays, fs, order=5, delta=1e-12, maxiter=10):
     while mean_squared_error >= delta2:
         logger.debug("Computing iteration %d", count + 1)
         if count >= maxiter:
-            logger.warning("Maximum number of iterations %d reached, "
-                           "returning current advancement", maxiter)
+            logger.warning(
+                "Maximum number of iterations %d reached, "
+                "returning current advancement",
+                maxiter,
+            )
             break
         advancements_prev = advancements
         advancements = timeshift(delays, advancements_prev * fs, order=order)
@@ -227,8 +243,12 @@ def calculate_advancements(delays, fs, order=5, delta=1e-12, maxiter=10):
         cut_end = k_max + num_tabs // 2
         difference = (advancements - advancements_prev)[cut_start:-cut_end]
         mean_squared_error = np.mean(difference**2)
-        logger.debug("Mean squared error of iteration %d: '%f' (aim at %f)",
-            count + 1, mean_squared_error, delta2)
+        logger.debug(
+            "Mean squared error of iteration %d: '%f' (aim at %f)",
+            count + 1,
+            mean_squared_error,
+            delta2,
+        )
         count += 1
 
     return advancements
